#!/usr/bin/env python3
"""
Author : Xinyuan Chen <45612704+tddschn@users.noreply.github.com>
Date   : 2022-06-02
Purpose: Why not?
"""

from virustotal_tddschn.virustotal_sum_search import (
    get_args,
    print_path_and_open_vt_link,
    brew_get_file_path,
    get_checksum_from_brew_file,
    get_brew_cache_path,
    sha256_checksum,
)
from . import __app_name__, __description__, __version__


def main():
    args = get_args(
        __app_name__, __version__, __description__, brew_related_options_only=True
    )
    if brew_cache := args.brew_cache:
        file_path = get_brew_cache_path(brew_cache, use_cask=args.cask)
        hash = sha256_checksum(file_path)  # type: ignore
        print_path_and_open_vt_link(file_path, hash, args)
    else:
        brew_file_path = brew_get_file_path(brew_name=args.brew, use_cask=args.cask)
        hash = get_checksum_from_brew_file(brew_file_path=brew_file_path)
        file_path = brew_file_path
        print_path_and_open_vt_link(file_path, hash, args)


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['brew_virustotal']

package_data = \
{'': ['*']}

install_requires = \
['virustotal-tddschn>=0.1.4,<0.2.0']

entry_points = \
{'console_scripts': ['brew-vt = brew_virustotal.cli:main']}

setup_kwargs = {
    'name': 'brew-virustotal',
    'version': '0.1.2',
    'description': 'Check Homebrew formulae and casks with VirusTotal',
    'long_description': '',
    'author': 'Xinyuan Chen',
    'author_email': '45612704+tddschn@users.noreply.github.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/tddschn/brew-virustotal',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
